acquire_lock

Function acquire_lock 

pub fn acquire_lock<'a, T>(
    mutex: &'a Mutex<T>,
    context: &str,
) -> MutexGuard<'a, T>
Acquire a mutex lock, recovering from poisoning with a warning.

Victauri’s mutex-protected data is append-only logs and registries where stale data is preferable to crashing the testing framework.