#[non_exhaustive]pub enum GhostSource {
FrontendOnly,
RegistryOnly,
}Expand description
Indicates which side of the IPC boundary a ghost command was found on.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FrontendOnly
Command invoked from the frontend but not registered in the backend.
RegistryOnly
Command registered in the backend but never invoked from the frontend.