Core types and protocol for Victauri — full-stack introspection for Tauri apps via MCP.
This crate provides the shared type system used by all Victauri crates. It has no Tauri dependency and can be used independently for testing.
Re-exports
pub use error::VictauriError;pub use event::AppEvent;pub use event::EventLog;pub use event::IpcCall;pub use event::IpcResult;pub use recording::EventRecorder;pub use recording::RecordedEvent;pub use recording::RecordedSession;pub use recording::StateCheckpoint;pub use registry::CommandArg;pub use registry::CommandInfo;pub use registry::CommandRegistry;pub use registry::ScoredCommand;pub use snapshot::DomElement;pub use snapshot::DomSnapshot;pub use snapshot::WindowState;pub use types::MemoryDelta;pub use types::RefHandle;pub use types::VerificationResult;pub use verification::AssertionResult;pub use verification::GhostCommand;pub use verification::GhostCommandReport;pub use verification::GhostSource;pub use verification::IpcIntegrityReport;pub use verification::SemanticAssertion;pub use verification::check_ipc_integrity;pub use verification::detect_ghost_commands;pub use verification::evaluate_assertion;pub use verification::verify_state;